"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.createHeadlessCmsImportExportCrud = void 0;
var _useCases = require("./useCases");
var _handlerGraphql = require("@webiny/handler-graphql");
var _exportContentEntries = require("./useCases/exportContentEntries");
var _urlSigner = require("../tasks/utils/urlSigner");
var _getBucket = require("../tasks/utils/helpers/getBucket");
var _s3Client = require("../tasks/utils/helpers/s3Client");
var _abortImportFromUrl = require("./useCases/abortImportFromUrl");
const createHeadlessCmsImportExportCrud = async context => {
  const urlSigner = new _urlSigner.UrlSigner({
    bucket: (0, _getBucket.getBucket)(),
    client: (0, _s3Client.createS3Client)()
  });
  const getExportContentEntriesUseCase = new _useCases.GetExportContentEntriesUseCase({
    getTask: context.tasks.getTask,
    urlSigner
  });
  const listExportContentEntriesUseCase = new _useCases.ListExportContentEntriesUseCase({
    listTasks: context.tasks.listTasks
  });
  const validateImportFromUrlUseCase = new _useCases.ValidateImportFromUrlUseCase({
    getModelToAstConverter: context.cms.getModelToAstConverter,
    getModel: context.cms.getModel
  });
  const validateImportFromUrlIntegrityUseCase = new _useCases.ValidateImportFromUrlIntegrityUseCase({
    triggerTask: context.tasks.trigger
  });
  const getValidateImportFromUrlIntegrityUseCase = new _useCases.GetValidateImportFromUrlUseCase({
    getTask: context.tasks.getTask
  });
  const importFromUrlUseCase = new _useCases.ImportFromUrlUseCase({
    updateTask: context.tasks.updateTask,
    getTask: context.tasks.getTask,
    triggerTask: context.tasks.trigger
  });
  const getImportFromUrlUseCase = new _useCases.GetImportFromUrlUseCase({
    getTask: context.tasks.getTask
  });
  const exportContentEntriesUseCase = new _exportContentEntries.ExportContentEntriesUseCase({
    triggerTask: context.tasks.trigger
  });
  const abortExportContentEntriesUseCase = new _useCases.AbortExportContentEntriesUseCase({
    abortTask: context.tasks.abort
  });
  const abortImportFromUrlUseCase = new _abortImportFromUrl.AbortImportFromUrlUseCase({
    getTaskUseCase: getImportFromUrlUseCase,
    abortTask: context.tasks.abort
  });
  const getExportContentEntries = async params => {
    const result = await getExportContentEntriesUseCase.execute(params);
    if (!result) {
      throw new _handlerGraphql.NotFoundError(`Export content entries task with id "${params.id}" not found.`);
    }
    return result;
  };
  const listExportContentEntries = async params => {
    return listExportContentEntriesUseCase.execute(params);
  };
  const exportContentEntries = async params => {
    return exportContentEntriesUseCase.execute(params);
  };
  const abortExportContentEntries = async params => {
    return abortExportContentEntriesUseCase.execute(params);
  };
  const validateImportFromUrl = async params => {
    const {
      files,
      model
    } = await validateImportFromUrlUseCase.execute({
      data: params.data
    });
    const result = await validateImportFromUrlIntegrityUseCase.execute({
      model,
      files
    });
    return {
      files,
      modelId: model.modelId,
      ...result
    };
  };
  const getValidateImportFromUrl = async params => {
    const result = await getValidateImportFromUrlIntegrityUseCase.execute(params);
    if (!result) {
      throw new _handlerGraphql.NotFoundError(`Validate import from URL task with id "${params.id}" not found.`);
    }
    return result;
  };
  const importFromUrl = async params => {
    const result = await importFromUrlUseCase.execute(params);
    if (!result) {
      throw new _handlerGraphql.NotFoundError(`Import from URL task with id "${params.id}" not found.`);
    }
    return result;
  };
  const getImportFromUrl = async params => {
    const result = await getImportFromUrlUseCase.execute(params);
    if (!result) {
      throw new _handlerGraphql.NotFoundError(`Import from URL task with id "${params.id}" not found.`);
    }
    return result;
  };
  const abortImportFromUrl = async params => {
    return await abortImportFromUrlUseCase.execute(params);
  };
  return {
    getExportContentEntries,
    listExportContentEntries,
    exportContentEntries,
    abortExportContentEntries,
    validateImportFromUrl,
    getValidateImportFromUrl,
    importFromUrl,
    getImportFromUrl,
    abortImportFromUrl
  };
};
exports.createHeadlessCmsImportExportCrud = createHeadlessCmsImportExportCrud;

//# sourceMappingURL=index.js.map