"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.makeSureModelsAreIdentical = void 0;
var _utils = require("@webiny/api-headless-cms/utils");
var _error = require("@webiny/error");
const getModelValues = ast => {
  const traverser = new _utils.ModelFieldTraverser();
  const results = [];
  traverser.traverse(ast, ({
    field,
    path
  }) => {
    const ref = field.settings?.models ? `#R#${field.settings.models.map(m => m.modelId).sort().join(",")}` : "";
    const key = `${field.type}@${path.join(".")}#${field.multipleValues ? "m" : "s"}${ref}`;
    results.push({
      key,
      field,
      path: path.join(".")
    });
  });
  return results;
};
const makeSureModelsAreIdentical = params => {
  const {
    getModelToAstConverter,
    model,
    target
  } = params;
  const converter = getModelToAstConverter();
  const modelAst = converter.toAst(model);
  const targetAst = converter.toAst(target);
  const modelValues = getModelValues(modelAst);
  const targetValues = getModelValues(targetAst);
  /**
   * First we will go through the model from the database.
   * Then we will go through the exported model and check against the model from the database.
   */
  for (const value of modelValues) {
    if (targetValues.some(v => v.key === value.key)) {
      continue;
    }
    throw new _error.WebinyError({
      message: `Field "${value.field.fieldId}" not found in the model provided via the JSON data.`,
      code: "MODEL_FIELD_NOT_FOUND",
      data: {
        field: value,
        targetValues,
        modelValues
      }
    });
  }
  for (const value of targetValues) {
    if (modelValues.some(v => v.key === value.key)) {
      continue;
    }
    throw new _error.WebinyError({
      message: `Field "${value.field.fieldId}" not found in the model from the database.`,
      code: "MODEL_FIELD_NOT_FOUND",
      data: {
        ...value
      }
    });
  }
};
exports.makeSureModelsAreIdentical = makeSureModelsAreIdentical;

//# sourceMappingURL=makeSureModelsAreIdentical.js.map