"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault").default;
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.createResolvers = void 0;
var _utils = require("@webiny/utils");
var _handlerGraphql = require("@webiny/handler-graphql");
var _zod = _interopRequireDefault(require("zod"));
var _security = require("./security");
const validateAbortExportContentEntries = _zod.default.object({
  id: _zod.default.string()
});
const validateGetExportContentEntries = _zod.default.object({
  id: _zod.default.string()
});
const validateListExportContentEntries = _zod.default.object({
  limit: _zod.default.number().optional().default(50),
  after: _zod.default.string().optional()
});
const validateImportFromUrl = _zod.default.object({
  data: _zod.default.string().or(_zod.default.object({}).passthrough())
});
const getValidateImportFromUrl = _zod.default.object({
  id: _zod.default.string()
});
const getImportFromUrl = _zod.default.object({
  id: _zod.default.string()
});
const importFromUrlValidation = _zod.default.object({
  id: _zod.default.string(),
  maxInsertErrors: _zod.default.number().optional().default(100),
  overwrite: _zod.default.boolean().optional().default(false)
});
const abortImportFromUrl = _zod.default.object({
  id: _zod.default.string()
});
const validateExportContentEntriesInput = _zod.default.object({
  exportAssets: _zod.default.boolean().optional().default(false),
  limit: _zod.default.number().optional(),
  where: _zod.default.object({}).passthrough().optional().default({}),
  sort: _zod.default.array(_zod.default.string()).optional()
});
/**
 * Create export resolver for each of the models given.
 */
const createExportContentEntries = models => {
  return models.reduce((resolvers, model) => {
    resolvers[`export${model.pluralApiName}ContentEntries`] = async (_, input, context) => {
      return (0, _handlerGraphql.resolve)(async () => {
        await (0, _security.checkPermissions)(context);
        const result = validateExportContentEntriesInput.safeParse(input);
        if (!result.success) {
          throw (0, _utils.createZodError)(result.error);
        }
        return await context.cmsImportExport.exportContentEntries({
          ...result.data,
          modelId: model.modelId,
          sort: result.data.sort ? result.data.sort : undefined,
          where: result.data.where ? result.data.where : undefined
        });
      });
    };
    return resolvers;
  }, {});
};
const createResolvers = models => {
  return {
    Query: {
      async getExportContentEntries(_, input, context) {
        return (0, _handlerGraphql.resolve)(async () => {
          await (0, _security.checkPermissions)(context);
          const result = validateGetExportContentEntries.safeParse(input);
          if (!result.success) {
            throw (0, _utils.createZodError)(result.error);
          }
          return await context.cmsImportExport.getExportContentEntries(result.data);
        });
      },
      async listExportContentEntries(_, input, context) {
        return (0, _handlerGraphql.resolveList)(async () => {
          await (0, _security.checkPermissions)(context);
          const result = validateListExportContentEntries.safeParse(input);
          if (!result.success) {
            throw (0, _utils.createZodError)(result.error);
          }
          return await context.cmsImportExport.listExportContentEntries(result.data);
        });
      },
      async getValidateImportFromUrl(_, input, context) {
        return (0, _handlerGraphql.resolve)(async () => {
          await (0, _security.checkPermissions)(context);
          const result = getValidateImportFromUrl.safeParse(input);
          if (!result.success) {
            throw (0, _utils.createZodError)(result.error);
          }
          return await context.cmsImportExport.getValidateImportFromUrl(result.data);
        });
      },
      async getImportFromUrl(_, input, context) {
        return (0, _handlerGraphql.resolve)(async () => {
          await (0, _security.checkPermissions)(context);
          const result = getImportFromUrl.safeParse(input);
          if (!result.success) {
            throw (0, _utils.createZodError)(result.error);
          }
          return await context.cmsImportExport.getImportFromUrl(result.data);
        });
      }
    },
    Mutation: {
      ...createExportContentEntries(models),
      async abortExportContentEntries(_, input, context) {
        return (0, _handlerGraphql.resolve)(async () => {
          await (0, _security.checkPermissions)(context);
          const result = validateAbortExportContentEntries.safeParse(input);
          if (!result.success) {
            throw (0, _utils.createZodError)(result.error);
          }
          return await context.cmsImportExport.abortExportContentEntries(result.data);
        });
      },
      async validateImportFromUrl(_, input, context) {
        return (0, _handlerGraphql.resolve)(async () => {
          await (0, _security.checkPermissions)(context);
          const result = validateImportFromUrl.safeParse(input);
          if (!result.success) {
            throw (0, _utils.createZodError)(result.error);
          }
          return await context.cmsImportExport.validateImportFromUrl(result.data);
        });
      },
      async importFromUrl(_, input, context) {
        return (0, _handlerGraphql.resolve)(async () => {
          await (0, _security.checkPermissions)(context);
          const result = importFromUrlValidation.safeParse(input);
          if (!result.success) {
            throw (0, _utils.createZodError)(result.error);
          }
          return await context.cmsImportExport.importFromUrl(result.data);
        });
      },
      async abortImportFromUrl(_, input, context) {
        return (0, _handlerGraphql.resolve)(async () => {
          await (0, _security.checkPermissions)(context);
          const result = abortImportFromUrl.safeParse(input);
          if (!result.success) {
            throw (0, _utils.createZodError)(result.error);
          }
          return await context.cmsImportExport.abortImportFromUrl(result.data);
        });
      }
    }
  };
};
exports.createResolvers = createResolvers;

//# sourceMappingURL=resolvers.js.map