"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.createExportContentAssets = void 0;
var _ExportContentAssets = require("./exportContentAssets/ExportContentAssets");
var _clientS = require("@webiny/aws-sdk/client-s3");
var _getBucket = require("../utils/helpers/getBucket");
var _cmsAssetsZipper = require("../utils/cmsAssetsZipper");
var _upload = require("../utils/upload");
var _archiver = require("../utils/archiver");
var _zipper = require("../utils/zipper");
var _constants = require("../constants");
const createExportContentAssets = () => {
  const client = (0, _clientS.createS3Client)();
  const bucket = (0, _getBucket.getBucket)();
  const createUpload = (0, _upload.createUploadFactory)({
    client,
    bucket
  });
  const createCmsAssetsZipper = config => {
    const upload = createUpload(config.filename);
    const archiver = (0, _archiver.createArchiver)({
      format: "zip",
      options: {
        gzip: true,
        /**
         * No point in compressing the assets, since they are already compressed.
         */
        gzipOptions: {
          level: 0
        },
        comment: _constants.WEBINY_EXPORT_ASSETS_EXTENSION
      }
    });
    const zipper = new _zipper.Zipper({
      upload,
      archiver
    });
    return new _cmsAssetsZipper.CmsAssetsZipper({
      entryFetcher: config.entryFetcher,
      createEntryAssets: config.createEntryAssets,
      createEntryAssetsResolver: config.createEntryAssetsResolver,
      fileFetcher: config.fileFetcher,
      zipper
    });
  };
  return new _ExportContentAssets.ExportContentAssets({
    createCmsAssetsZipper
  });
};
exports.createExportContentAssets = createExportContentAssets;

//# sourceMappingURL=createExportContentAssets.js.map