"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.createExportContentEntries = void 0;
var _clientS = require("@webiny/aws-sdk/client-s3");
var _getBucket = require("../utils/helpers/getBucket");
var _ExportContentEntries = require("./exportContentEntries/ExportContentEntries");
var _cmsEntryZipper = require("../utils/cmsEntryZipper");
var _upload = require("../utils/upload");
var _archiver = require("../utils/archiver");
var _zipper = require("../utils/zipper");
var _entryAssets = require("../utils/entryAssets");
var _UniqueResolver = require("../utils/uniqueResolver/UniqueResolver");
var _constants = require("../constants");
const createExportContentEntries = () => {
  const client = (0, _clientS.createS3Client)();
  const bucket = (0, _getBucket.getBucket)();
  const createUpload = (0, _upload.createUploadFactory)({
    client,
    bucket
  });
  const createCmsEntryZipper = config => {
    const upload = createUpload(config.filename);
    const archiver = (0, _archiver.createArchiver)({
      format: "zip",
      options: {
        gzip: true,
        gzipOptions: {
          level: 9
        },
        comment: _constants.WEBINY_EXPORT_ENTRIES_EXTENSION
      }
    });
    const zipper = new _zipper.Zipper({
      upload,
      archiver
    });
    return new _cmsEntryZipper.CmsEntryZipper({
      fetcher: config.fetcher,
      zipper,
      entryAssets: new _entryAssets.EntryAssets({
        uniqueResolver: new _UniqueResolver.UniqueResolver(),
        traverser: config.traverser
      }),
      uniqueAssetsResolver: new _UniqueResolver.UniqueResolver()
    });
  };
  return new _ExportContentEntries.ExportContentEntries({
    createCmsEntryZipper
  });
};
exports.createExportContentEntries = createExportContentEntries;

//# sourceMappingURL=createExportContentEntries.js.map