"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.ImportFromUrlControllerDownloadStep = void 0;
var _constants = require("../../constants");
var _getBackOffSeconds = require("../../utils/helpers/getBackOffSeconds");
var _types = require("../../../types");
var _ImportFromUrlController = require("../abstractions/ImportFromUrlController");
var _getChildTasks = require("./getChildTasks");
class ImportFromUrlControllerDownloadStep {
  async execute(params) {
    const {
      context,
      response,
      input,
      trigger,
      store
    } = params;
    const task = store.getTask();
    const step = input.steps[_ImportFromUrlController.IImportFromUrlControllerInputStep.DOWNLOAD];
    if (!step?.triggered) {
      const files = input.files.filter(file => {
        return file.type === _types.CmsImportExportFileType.ENTRIES || file.type === _types.CmsImportExportFileType.ASSETS;
      });
      if (files.length === 0) {
        return response.error({
          message: `No files found in the provided data.`,
          code: "NO_FILES_FOUND"
        });
      }
      for (const file of files) {
        await trigger({
          name: `Import From Url - Download`,
          definition: _constants.IMPORT_FROM_URL_DOWNLOAD_TASK,
          input: {
            file,
            modelId: input.modelId
          }
        });
      }
      const output = {
        ...input,
        steps: {
          ...input.steps,
          [_ImportFromUrlController.IImportFromUrlControllerInputStep.DOWNLOAD]: {
            ...step,
            triggered: true
          }
        }
      };
      return response.continue(output, {
        seconds: (0, _getBackOffSeconds.getBackOffSeconds)(task.iterations)
      });
    } else if (step.finished !== true) {
      const {
        failed,
        running,
        invalid,
        aborted,
        done,
        collection
      } = await (0, _getChildTasks.getChildTasks)({
        context,
        task,
        definition: _constants.IMPORT_FROM_URL_DOWNLOAD_TASK
      });

      /**
       * If there are any running tasks, we should continue waiting.
       */
      if (running.length > 0) {
        return response.continue(input, {
          seconds: (0, _getBackOffSeconds.getBackOffSeconds)(task.iterations)
        });
      } else if (collection.length === 0) {
        return response.error({
          message: "No download tasks found. We are not continuing.",
          code: "NO_DOWNLOAD_TASKS"
        });
      }
      const files = collection.map(item => {
        return item.output?.file;
      }).filter(file => {
        return !!file;
      });
      const output = {
        ...input,
        steps: {
          ...input.steps,
          [_ImportFromUrlController.IImportFromUrlControllerInputStep.DOWNLOAD]: {
            ...step,
            files,
            failed,
            invalid,
            aborted,
            done,
            finished: true
          }
        }
      };
      if (failed.length > 0 || aborted.length > 0 || invalid.length > 0) {
        return response.error({
          message: "Some download tasks failed.",
          code: "DOWNLOAD_FAILED",
          data: {
            failed,
            aborted,
            invalid
          }
        });
      }
      return response.continue(output);
    }
    return response.error({
      message: "Impossible to get to this point. Fatal error."
    });
  }
}
exports.ImportFromUrlControllerDownloadStep = ImportFromUrlControllerDownloadStep;

//# sourceMappingURL=ImportFromUrlControllerDownloadStep.js.map