"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.ImportFromUrlProcessEntries = void 0;
var _types = require("../../../types");
var _ImportFromUrlProcessEntriesDecompress = require("./ImportFromUrlProcessEntriesDecompress");
var _ImportFromUrlProcessEntriesInsert = require("./ImportFromUrlProcessEntriesInsert");
class ImportFromUrlProcessEntries {
  constructor(params) {
    this.fileFetcher = params.fileFetcher;
    this.reader = params.reader;
    this.decompressor = params.decompressor;
  }
  async run(params) {
    const {
      context,
      response,
      input
    } = params;
    if (!input.modelId) {
      return response.error({
        message: `Missing "modelId" in the input.`,
        code: "MISSING_MODEL_ID"
      });
    } else if (!input.file) {
      return response.error({
        message: `No file found in the provided data.`,
        code: "NO_FILE_FOUND"
      });
    } else if (input.file.type !== _types.CmsImportExportFileType.ENTRIES) {
      return response.error({
        message: `Invalid file type. Expected "${_types.CmsImportExportFileType.ENTRIES}" but got "${input.file.type}".`,
        code: "INVALID_FILE_TYPE"
      });
    }
    let entryManager;
    try {
      entryManager = await context.cms.getEntryManager(input.modelId);
    } catch (ex) {
      return response.error({
        message: `Model "${input.modelId}" not found.`,
        code: "MODEL_NOT_FOUND"
      });
    }
    if (!input.decompress?.done) {
      try {
        const decompress = new _ImportFromUrlProcessEntriesDecompress.ImportFromUrlProcessEntriesDecompress({
          reader: this.reader,
          decompressor: this.decompressor
        });
        return await decompress.run(params);
      } catch (ex) {
        console.error(ex);
        return response.error({
          message: ex.message,
          code: ex.code || "DECOMPRESS_ERROR",
          data: ex.data,
          stack: ex.stack
        });
      }
    }
    try {
      const insert = new _ImportFromUrlProcessEntriesInsert.ImportFromUrlProcessEntriesInsert({
        entryManager,
        fileFetcher: this.fileFetcher
      });
      return await insert.run(params);
    } catch (ex) {
      return response.error({
        message: ex.message,
        code: ex.code || "DECOMPRESS_ERROR",
        data: ex.data,
        stack: ex.stack
      });
    }
  }
}
exports.ImportFromUrlProcessEntries = ImportFromUrlProcessEntries;

//# sourceMappingURL=ImportFromUrlProcessEntries.js.map